@@ -1,8 +1,8 @@
-/* Time-stamp: <2011-02-16 10:44:02 poser>
+/* Time-stamp: <2019-06-28 07:33:47 poser>
  *
  * Convert text containing various 7-bit ASCII escapes to UTF-8 Unicode.
  *
- * Copyright (C) 2005-2011 William J. Poser (billposer@alum.mit.edu)
+ * Copyright (C) 2005-2019 William J. Poser (billposer@alum.mit.edu)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License
@@ -86,7 +86,7 @@ ShowVersion(FILE *fp)
 }
 
 void Copyright() {
-  fprintf(stderr,"Copyright (C) 2004-2011 William J. Poser\n");
+  fprintf(stderr,"Copyright (C) 2004-2019 William J. Poser\n");
   fprintf(stderr,"This program is free software; you can redistribute\n\
 it and/or modify it under the terms of version 3 of\n\
 the GNU General Public License as published by the\n\
@@ -201,7 +201,8 @@ static char *Formats [] = {
 
 int main (int ac, char *av[])
 {
-  char *SplitFormat = "\\%1[uU]%X%n"; /* This is for BMPSplit */
+  char *SplitLowFormat  = "\\u%4X%n";
+  char *SplitHighFormat = "\\U%8X%n";
 
   char *fmt = Formats[STDX];		/* Default is plain hex format */
   char afmt [AFMTSIZE];
@@ -228,7 +229,6 @@ int main (int ac, char *av[])
   char *str;
   char *iptr;
   int eof;
-  char SplitStr[3];
   char enam[16];
   char tmpstr [16];
   unsigned char b1;		/* Used for byte-wise encoding */
@@ -341,7 +341,7 @@ int main (int ac, char *av[])
 #endif
 
    if( (FType == RAWX) && (!PureP) ) {
-     fprintf(stderr,_("It isn't possible reliably to parse raw hex unicode out of ASCII text.\n"));
+     fprintf(stderr,_("It isn't possible reliably to parse raw hex unicode out of impure ASCII text.\nIf your input text is pure, add the -p flag.\n"));
      exit(BADOPTION);
    }
 
@@ -365,14 +365,15 @@ int main (int ac, char *av[])
 
    snprintf(afmt,AFMTSIZE,"%s%%n",fmt);	/* Add %n for NConsumed */
 
+#ifdef DEBUGBUILD
+   fprintf(stderr,"Setup completed.\n");fflush(stderr); /* debug */
+#endif
+
    /*
     * This is the case in which the input consists entirely of escapes
     * except for arbitrary (but non-null) amounts of intervening whitespace.
     */
 
-#ifdef DEBUGBUILD
-   fprintf(stderr,"Setup completed.\n");fflush(stderr); /* debug */
-#endif
    if(PureP) {
      GetWordLineNo = 1;
      while(1){
@@ -538,18 +539,25 @@ int main (int ac, char *av[])
 
      while (*iptr) {
        if(BMPSplitP) {
-	 if(sscanf(iptr,SplitFormat,&SplitStr,&num,&NConsumed)) {
-	   if( (num <= 0xFFFF) && (SplitStr[0] == 'U')) {
-	     fprintf(stderr,_("Warning: the code \\U%1$08lX at line %2$lu falls within the BMP.\n"),
-		     num,LineNo);
+	 /* Check for 4 digit case, then 8 digit case */
+	 if(sscanf(iptr,SplitLowFormat,&num,&NConsumed)) {
+	   if (NConsumed == 6) { /* 4 hex digits */
+	     putu8(num);
+	     iptr+=NConsumed;
+	     TokenNumber++;
 	   }
-	   if( (num > 0xFFFF) && (SplitStr[0] == 'u')) {
-	     fprintf(stderr,_("Warning: the code \\u%1$08lX at line %2$lu falls outside the BMP.\n"),
-		     num,LineNo);
+	   else putchar(*iptr++);
+	 }
+	 else if(sscanf(iptr,SplitHighFormat,&num,&NConsumed)) {
+	   if (NConsumed == 10) { /* 8 hex digits */
+	     putu8(num);
+	     iptr+=NConsumed;
+	     TokenNumber++;
+	     if (num < 0x10000) {
+	       fprintf(stderr,"ascii2uni: warning - \\U escape encodes character within BMP at line %lu\n", LineNo);
+	     }
 	   }
-	   putu8(num);
-	   iptr+=NConsumed;
-	   TokenNumber++;
+	   else putchar(*iptr++);
 	 }
 	 else putchar(*iptr++);
        }
@@ -594,6 +602,7 @@ int main (int ac, char *av[])
 	     TokenNumber++;
 	   }
 	   else {
+	     /* BUG - here is where jidanni is getting a segfault - I get infinitely many error messages instead. The error only occurs if the pseudo-entity has no terminating semi-colon */
 	     fprintf(stderr,"ascii2uni: unknown HTML/HDML character entity \"&%s;\" at line %lu\n",
 		     enam,LineNo);
 	     putu8(UNI_REPLACEMENT_CHAR);
