@@ -1,3 +1,23 @@
+/* Time-stamp: <2008-03-10 12:05:41 poser>
+ *
+ * Copyright (C) 2005-2007 William J. Poser (billposer@alum.mit.edu)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of version 3 of the GNU General Public License as published by
+ * the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * or go to the web page:  http://www.gnu.org/licenses/gpl.txt.
+ */
+
+
 #include "config.h"
 #include <stdlib.h>
 #include "unicode.h"
@@ -507,7 +527,17 @@ static struct ent CodeEntityTable[] = {
 {"diams",0x2666}
 };
 
+static struct ent HDMLEntityCodeTable[] = {
+{"&gt;",0x003E},
+{"&lt;",0x003C},
+{"&amp;",0x0026},
+{"&dol;",0x0024},
+{"&nbsp;",0x00A0}
+};
+
+
 static int Entities = sizeof(EntityCodeTable)/sizeof(struct ent);
+static int HDMLEntities = sizeof(HDMLEntityCodeTable)/sizeof(struct ent);
 
 /*
  * Look up an HTML character entity name and return the corresponding
@@ -567,18 +597,43 @@ LookupHDMLEntityForCode (UTF32 c) {
   switch (c)
     {
     case 0x003E:
-      return "&#3E;";
+      return "&gt;";
     case 0x003C:
-      return "&#3C;";
+      return "&lt;";
     case 0x0026:
-      return "&#26;";
+      return "&amp;";
     case 0x0024:
-      return "&#24;";
+      return "&dol;";
     case 0xA0:
-      return "&#A0;";
+      return "&nbsp;";
     default:
       return NULL;
   }
 }
 
+/*
+ * Look up an HDML character entity name and return the corresponding
+ *Unicode codepoint or 0x00 if not found.
+ */
+
+UTF32
+LookupCodeForHDMLEntity (char *s) {
+  int l;			/* Lower bound of region */
+  int u;			/* Upper bound of region */
+  int m;			/* Midpoint of region */
+  int c;
+  
+  l = 0;
+  u = HDMLEntities -1;
+
+  /* Standard binary search */
+  while(l <= u){
+    m = (l + u) / 2;
+    c =strcmp(s,HDMLEntityCodeTable[m].name);
+    if (c < 0) u = m - 1;
+    else if(c > 0)  l = m + 1;
+    else return(HDMLEntityCodeTable[m].code);
+  }
+  return 0L;
+}
 
