@@ -25,11 +25,13 @@
 #define BYTED  23
 #define BYTEH  24
 #define OOXML  25
-#define CHENT  26	/* Used only by ascii2uni */
-#define IFMT   27
-#define JFMT   28
-#define KFMT   29
-#define APACHE 30
+#define PCTUX  26
+#define CHENT  27	/* Used only by ascii2uni */
+#define IFMT   28
+#define JFMT   29
+#define KFMT   30
+#define APACHE 31
+#define UTF8ANGLE 32
 
 
 
