@@ -1,9 +1,9 @@
-/* Time-stamp: <2011-05-14 19:03:13 poser>
+/* Time-stamp: <2022-08-21 17:07:14 poser>
  *
  * Converts UTF-8 Unicode to pure 7-bit ASCII using any of a number
  * of different representations. 
  * 
- * Copyright (C) 2004-2011 William J. Poser (billposer@alum.mit.edu)
+ * Copyright (C) 2004-2022 William J. Poser (billposer@alum.mit.edu)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License as published by
@@ -94,7 +94,7 @@ ShowVersion(FILE *fp)
 
 
 void Copyright (void) {
-  fprintf(stderr,"Copyright (C) 2004-2011 William J. Poser\n");
+  fprintf(stderr,"Copyright (C) 2004-2022 William J. Poser\n");
   fprintf(stderr,"This program is free software; you can redistribute\n\
 it and/or modify it under the terms of version 3 of\n\
 the GNU General Public License as published by the\n\
@@ -115,6 +115,7 @@ and for conversion even of newline and space characters.\n"));
   fprintf(stderr,_("       -h Print this usage message.\n"));
   fprintf(stderr,_("       -v Print version information.\n"));
   fprintf(stderr,_("       -L List format specifications.\n"));
+  fprintf(stderr,_("       -A List the conversions performed by the -e option.\n"));
   fprintf(stderr,_("       -E List the expansions performed by the -x option.\n"));
   fprintf(stderr,_("       -q Quiet. Do not chat unnecessarily while working.\n"));
   fprintf(stderr,_("       -a <format specification>.\n"));
@@ -160,6 +161,7 @@ void ListExpansions(void){
   fprintf(stderr,_("          U+02A6 SMALL LETTER TS DIGRAPH     -> ts\n"));
   fprintf(stderr,_("          U+2026 HORIZONTAL ELLIPSIS         -> ...\n"));
   fprintf(stderr,_("          U+20AC EURO SIGN                   -> euro\n"));
+  fprintf(stderr,_("          U+2122 TRADEMARK                   -> (tm)\n"));
   fprintf(stderr,_("          U+2190 LEFTWARDS ARROW             -> <-\n"));
   fprintf(stderr,_("          U+2192 RIGHTWARDS ARROW            -> ->\n"));
   fprintf(stderr,_("          U+21D0 LEFTWARDS DOUBLE ARROW      -> <=\n"));
@@ -199,6 +201,7 @@ void ListSingleApproximations(void){
   fprintf(stderr,_("          U+02A6 SMALL LETTER TS DIGRAPH     -> t\n"));
   fprintf(stderr,_("          U+2028 LINE SEPARATOR              -> newline\n"));
   fprintf(stderr,_("          U+2026 HORIZONTAL ELLIPSIS         -> .\n"));
+  fprintf(stderr,_("          U+2032 PRIME                       -> \'\n"));
   fprintf(stderr,_("          U+20AC EURO SIGN                   -> E\n"));
   fprintf(stderr,_("          U+2190 LEFTWARDS ARROW             -> <\n"));
   fprintf(stderr,_("          U+2192 RIGHTWARDS ARROW            -> >\n"));
@@ -551,6 +554,7 @@ int AscifyEquiv(UTF32 c) {
       putchar('o');
       break;
     case 0x2019:
+    case 0x2032:		/* prime */
     case 0x203A:
       putchar(0x27);		/* right or neutral single quote */
       break;
@@ -2595,6 +2599,12 @@ int ExpandToAscii(UTF32 c) {
       putchar('r');
       putchar('o');
       break;
+    case 0x2122:
+      putchar('(');
+      putchar('t');
+      putchar('m');
+      putchar(')');
+      break;
     case 0x2026:	/* Horizontal ellipsis */
     case 0x22EF:	/* Midline horizontal ellipsis */
       putchar('.');
@@ -2781,6 +2791,8 @@ int main (int ac, char *av[])
   char *e;
   unsigned char *ustr;	/* UTF8 string */
 
+  FILE *fp;
+
   extern int optind;
   extern int opterr;
   extern int optopt;
@@ -3046,8 +3058,9 @@ int main (int ac, char *av[])
       }
       exit(SUCCESS);
     }
-    else {
-      while( (ch = getchar()) != EOF) { 
+    else {			/* I think we need to read from infd here, not from stdin */
+      fp=fdopen(infd,"r");
+      while( (ch = fgetc(fp)) != EOF) { /* while( (ch = getchar()) != EOF) {  */
 	convp = 1;
 	if(ch <= 0x7F) convp = 0;
 	switch(ch) {
